@@ -70,17 +70,20 @@ class Endpoint(object):
         :Returns: Record (obj)
         """
         if model:
-            name = name.title().replace("_", "")
+            name = name.title().replace("_", "").replace("-", "")
             ret = getattr(model, name, Record)
         else:
             ret = Record
         return ret
 
-    def all(self):
+    def all(self, api_version=None):
         """Queries the 'ListView' of a given endpoint.
 
         Returns all objects from an endpoint.
 
+        :arg str,optional api_version: Override default or globally-set Nautobot REST API
+            version for this single request.
+
         :Returns: List of :py:class:`.Record` objects.
 
         :Examples:
@@ -89,11 +92,14 @@ class Endpoint(object):
         [test1-a3-oobsw2, test1-a3-oobsw3, test1-a3-oobsw4]
         >>>
         """
+
+        api_version = api_version or self.api.api_version
         req = Request(
             base="{}/".format(self.url),
             token=self.token,
             http_session=self.api.http_session,
             threading=self.api.threading,
+            api_version=api_version,
         )
 
         return response_loader(req.get(), self.return_obj, self)
@@ -108,6 +114,9 @@ class Endpoint(object):
             filter(). Any search argument the endpoint accepts can
             be added as a keyword arg.
 
+        :arg str,optional api_version: Override default or globally-set Nautobot REST API
+            version for this single request.
+
         :returns: A single :py:class:`.Record` object or None
 
         :raises ValueError: if kwarg search return more than one value.
@@ -132,6 +141,9 @@ class Endpoint(object):
         except IndexError:
             key = None
 
+        is_api_version = kwargs.pop("api_version") if kwargs.get("api_version") else None
+        api_version = is_api_version or self.api.api_version
+
         if not key:
             filter_lookup = self.filter(**kwargs)
             if filter_lookup:
@@ -145,7 +157,9 @@ class Endpoint(object):
                     return filter_lookup[0]
             return None
 
-        req = Request(key=key, base=self.url, token=self.token, http_session=self.api.http_session,)
+        req = Request(
+            key=key, base=self.url, token=self.token, http_session=self.api.http_session, api_version=api_version,
+        )
 
         try:
             resp = req.get()
@@ -157,7 +171,7 @@ class Endpoint(object):
 
         return response_loader(resp, self.return_obj, self)
 
-    def filter(self, *args, **kwargs):
+    def filter(self, *args, api_version=None, **kwargs):
         r"""Queries the 'ListView' of a given endpoint.
 
         Takes named arguments that match the usable filters on a
@@ -168,6 +182,8 @@ class Endpoint(object):
             accepted on given endpoint.
         :arg str,optional \**kwargs: Any search argument the
             endpoint accepts can be added as a keyword arg.
+        :arg str,optional api_version: Override default or globally-set
+            Nautobot REST API version for this single request.
 
         :Returns: A list of :py:class:`.Record` objects.
 
@@ -207,17 +223,19 @@ class Endpoint(object):
         if any(i in RESERVED_KWARGS for i in kwargs):
             raise ValueError("A reserved {} kwarg was passed. Please remove it " "try again.".format(RESERVED_KWARGS))
 
+        api_version = api_version or self.api.api_version
         req = Request(
             filters=kwargs,
             base=self.url,
             token=self.token,
             http_session=self.api.http_session,
             threading=self.api.threading,
+            api_version=api_version,
         )
 
         return response_loader(req.get(), self.return_obj, self)
 
-    def create(self, *args, **kwargs):
+    def create(self, *args, api_version=None, **kwargs):
         r"""Creates an object on an endpoint.
 
         Allows for the creation of new objects on an endpoint. Named
@@ -233,6 +251,8 @@ class Endpoint(object):
             properties of the objects to be created.
         :arg str \**kwargs: key/value strings representing
             properties on a json object.
+        :arg str,optional api_version: Override default or globally-set
+            Nautobot REST API version for this single request.
 
         :returns: A list or single :py:class:`.Record` object depending
             on whether a bulk creation was requested.
@@ -268,13 +288,15 @@ class Endpoint(object):
         ... ])
         """
 
-        req = Request(base=self.url, token=self.token, http_session=self.api.http_session,).post(
-            args[0] if args else kwargs
-        )
+        api_version = api_version or self.api.api_version
+
+        req = Request(
+            base=self.url, token=self.token, http_session=self.api.http_session, api_version=api_version,
+        ).post(args[0] if args else kwargs)
 
         return response_loader(req, self.return_obj, self)
 
-    def choices(self):
+    def choices(self, api_version=None):
         """Returns all choices from the endpoint.
 
         The returned dict is also saved in the endpoint object (in
@@ -283,6 +305,9 @@ class Endpoint(object):
         long-running applications, consider restarting them whenever Nautobot is
         upgraded, to prevent using stale choices data.
 
+        :arg str,optional api_version: Override default or globally-set
+            Nautobot REST API version for this single request.
+
         :Returns: Dict containing the available choices.
 
         :Example (from Nautobot 2.8.x):
@@ -306,7 +331,11 @@ class Endpoint(object):
         if self._choices:
             return self._choices
 
-        req = Request(base=self.url, token=self.api.token, http_session=self.api.http_session,).options()
+        api_version = api_version or self.api.api_version
+
+        req = Request(
+            base=self.url, token=self.api.token, http_session=self.api.http_session, api_version=api_version,
+        ).options()
         try:
             post_data = req["actions"]["POST"]
         except KeyError:
@@ -318,7 +347,7 @@ class Endpoint(object):
 
         return self._choices
 
-    def count(self, *args, **kwargs):
+    def count(self, *args, api_version=None, **kwargs):
         r"""Returns the count of objects in a query.
 
         Takes named arguments that match the usable filters on a
@@ -331,6 +360,8 @@ class Endpoint(object):
             accepted on given endpoint.
         :arg str,optional \**kwargs: Any search argument the
             endpoint accepts can be added as a keyword arg.
+        :arg str,optional api_version: Override default or globally-set
+            Nautobot REST API version for this single request.
 
         :Returns: Integer with count of objects returns by query.
 
@@ -355,7 +386,11 @@ class Endpoint(object):
         if any(i in RESERVED_KWARGS for i in kwargs):
             raise ValueError("A reserved {} kwarg was passed. Please remove it " "try again.".format(RESERVED_KWARGS))
 
-        ret = Request(filters=kwargs, base=self.url, token=self.token, http_session=self.api.http_session,)
+        api_version = api_version or self.api.api_version
+
+        ret = Request(
+            filters=kwargs, base=self.url, token=self.token, http_session=self.api.http_session, api_version=api_version
+        )
 
         return ret.get_count()
 
@@ -371,27 +406,31 @@ class DetailEndpoint(object):
         self.parent_obj = parent_obj
         self.custom_return = custom_return
         self.url = "{}/{}/{}/".format(parent_obj.endpoint.url, parent_obj.id, name)
+
         self.request_kwargs = dict(base=self.url, token=parent_obj.api.token, http_session=parent_obj.api.http_session,)
 
-    def list(self, **kwargs):
+    def list(self, api_version=None, **kwargs):
         r"""The view operation for a detail endpoint
 
         Returns the response from Nautobot for a detail endpoint.
 
         Args:
+            :arg str,optional api_version: Override default or globally set Nautobot REST API version for this single request.
             **kwargs: key/value pairs that get converted into url parameters when passed to the endpoint.
                 E.g. ``.list(method='get_facts')`` would be converted to ``.../?method=get_facts``.
 
         :returns: A dictionary or list of dictionaries retrieved from
             Nautobot.
         """
-        req = Request(**self.request_kwargs).get(add_params=kwargs)
+        api_version = api_version or self.parent_obj.api.api_version
+
+        req = Request(api_version=api_version, **self.request_kwargs).get(add_params=kwargs)
 
         if self.custom_return:
             return response_loader(req, self.custom_return, self.parent_obj.endpoint)
         return req
 
-    def create(self, data=None):
+    def create(self, data=None, api_version=None):
         """The write operation for a detail endpoint.
 
         Creates objects on a detail endpoint in Nautobot.
@@ -400,12 +439,16 @@ class DetailEndpoint(object):
             key/value pair of the items you're creating on the parent
             object. Defaults to empty dict which will create a single
             item with default values.
+        :args str,optional api_version: Override default or globally set
+            Nautobot REST API version for this single request.
 
         :returns: A dictionary or list of dictionaries its created in
             Nautobot.
         """
         data = data or {}
-        req = Request(**self.request_kwargs).post(data)
+        api_version = api_version or self.parent_obj.api.api_version
+
+        req = Request(api_version=api_version, **self.request_kwargs).post(data)
         if self.custom_return:
             return response_loader(req, self.custom_return, self.parent_obj.endpoint)
         return req
